@@ -27,9 +27,4 @@
 ] @type.qualifier
 
 (hlsl_attribute) @attribute
-
-(hlsl_attribute
-  [
-    "["
-    "]"
-  ] @attribute)
+(hlsl_attribute ["[" "]"] @attribute)
