@@ -1,6 +1,6 @@
 ;;; tree-sitter-langs-build.el --- Building grammar bundle -*- lexical-binding: t; coding: utf-8 -*-
 
-;; Copyright (C) 2021-2026 emacs-tree-sitter maintainers
+;; Copyright (C) 2021-2025 emacs-tree-sitter maintainers
 ;;
 ;; Author: Tuấn-Anh Nguyễn <ubolonton@gmail.com>
 ;; Maintainer: Jen-Chieh Shen <jcs090218@gmail.com>
@@ -74,8 +74,8 @@ If BUFFER is nil, `princ' is used to forward its stdout+stderr."
                      `(:buffer ,tree-sitter-langs--out)
                    `(:filter (lambda (proc string)
                                (princ string)))))
-         (proc (let ((process-environment (cons (format "TREE_SITTER_LIBDIR=%s"
-                                                        (tree-sitter-langs--bin-dir))
+         (proc (let ((process-environment (cons (format "TREE_SITTER_DIR=%s"
+                                                        tree-sitter-langs-grammar-dir)
                                                 process-environment)))
                  (apply #'make-process (append base output))))
          (exit-code (progn
@@ -161,18 +161,12 @@ git checkout."
        :paths (pcase lang-symbol
                 ;; XXX
                 ('csv '("csv" ("csv" . csv)))
-                ('fsharp '("fsharp" ("fsharp" . fsharp)))
-                ('ocaml '("grammars/ocaml" ("ocaml" . ocaml)))
-                ('ocaml-interface '("grammars/interface" ("ocaml-interface" . ocaml-interface)))
-                ('php '("php" ("php" . php)))
+                ('ocaml '("ocaml" ("interface" . ocaml-interface)))
+                ('ocaml-interface '("interface" ("interface" . ocaml-interface)))
                 ('typescript '("typescript" ("tsx" . tsx)))
                 ('xml '("xml" ("dtd" . dtd)))
                 ('markdown '("tree-sitter-markdown" ("tree-sitter-markdown" . markdown)))
                 ('markdown-inline '("tree-sitter-markdown-inline" ("tree-sitter-markdown-inline" . markdown)))
-                ;; lexd/twolc/xfst don't yet have major modes for Emacs:
-                ('rtx '(("tree-sitter-rtx" . rtx)))
-                ('cg '(("tree-sitter-cg" . cg)))
-                ('lexc '(("tree-sitter-lexc" . lexc)))
                 (_ '("")))))))
 
 (defun tree-sitter-langs--repo-status (lang-symbol)
@@ -239,7 +233,7 @@ latest commit."
 ;; ---------------------------------------------------------------------------
 ;;; Building language grammars.
 
-(defconst tree-sitter-langs--bundle-version "0.13.23"
+(defconst tree-sitter-langs--bundle-version "0.12.312"
   "Version of the grammar bundle.
 This should be bumped whenever a language submodule is updated, which should be
 infrequent (grammar-only changes).  It is different from the version of
@@ -264,7 +258,6 @@ infrequent (grammar-only changes).  It is different from the version of
     (astro)
     (cpp)
     (commonlisp)
-    (fennel)
     (hlsl)
     (glsl)
     (toml)
