@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "tree-sitter-langs" "0.13.30"
+(define-package "tree-sitter-langs" "20251019.1145"
   "Grammar bundle for tree-sitter."
-  '((emacs       "26.1")
+  '((emacs       "25.1")
     (tree-sitter "0.15.0"))
   :url "https://github.com/emacs-tree-sitter/tree-sitter-langs"
-  :commit "0d681622c0e8b5f8014fccba7519407a168f7bd8"
-  :revdesc "0d681622c0e8"
+  :commit "3b9a1f6bfa21ab01e1371f3725ddc6992a5cdb21"
+  :revdesc "3b9a1f6bfa21"
   :keywords '("languages" "tools" "parsers" "tree-sitter")
   :authors '(("Tuấn-Anh Nguyễn" . "ubolonton@gmail.com"))
   :maintainers '(("Jen-Chieh Shen" . "jcs090218@gmail.com")))
